SWDEV-240807 - Added Implementation for few more graph APIs

Change-Id: I76336a22233a208a3f54ff9e90f0c5bf4a1bddb4
Este commit está contenido en:
Anusha GodavarthySurya
2021-07-07 03:58:37 -07:00
padre 4aab5c29ff
commit e5cbfa8ca9
Se han modificado 7 ficheros con 224 adiciones y 3 borrados
+27
Ver fichero
@@ -236,14 +236,23 @@ enum hip_api_id_t {
HIP_API_ID_hipGetTextureObjectResourceViewDesc = HIP_API_ID_NONE,
HIP_API_ID_hipGetTextureObjectTextureDesc = HIP_API_ID_NONE,
HIP_API_ID_hipGetTextureReference = HIP_API_ID_NONE,
HIP_API_ID_hipGraphAddDependencies = HIP_API_ID_NONE,
HIP_API_ID_hipGraphAddKernelNode = HIP_API_ID_NONE,
HIP_API_ID_hipGraphAddMemcpyNode = HIP_API_ID_NONE,
HIP_API_ID_hipGraphAddMemsetNode = HIP_API_ID_NONE,
HIP_API_ID_hipGraphCreate = HIP_API_ID_NONE,
HIP_API_ID_hipGraphDestroy = HIP_API_ID_NONE,
HIP_API_ID_hipGraphExecDestroy = HIP_API_ID_NONE,
HIP_API_ID_hipGraphGetNodes = HIP_API_ID_NONE,
HIP_API_ID_hipGraphGetRootNodes = HIP_API_ID_NONE,
HIP_API_ID_hipGraphInstantiate = HIP_API_ID_NONE,
HIP_API_ID_hipGraphKernelNodeGetParams = HIP_API_ID_NONE,
HIP_API_ID_hipGraphKernelNodeSetParams = HIP_API_ID_NONE,
HIP_API_ID_hipGraphLaunch = HIP_API_ID_NONE,
HIP_API_ID_hipGraphMemcpyNodeGetParams = HIP_API_ID_NONE,
HIP_API_ID_hipGraphMemcpyNodeSetParams = HIP_API_ID_NONE,
HIP_API_ID_hipGraphMemsetNodeGetParams = HIP_API_ID_NONE,
HIP_API_ID_hipGraphMemsetNodeSetParams = HIP_API_ID_NONE,
HIP_API_ID_hipGraphicsGLRegisterBuffer = HIP_API_ID_NONE,
HIP_API_ID_hipGraphicsMapResources = HIP_API_ID_NONE,
HIP_API_ID_hipGraphicsResourceGetMappedPointer = HIP_API_ID_NONE,
@@ -3136,6 +3145,8 @@ typedef struct hip_api_data_s {
#define INIT_hipGetTextureObjectTextureDesc_CB_ARGS_DATA(cb_data) {};
// hipGetTextureReference()
#define INIT_hipGetTextureReference_CB_ARGS_DATA(cb_data) {};
// hipGraphAddDependencies()
#define INIT_hipGraphAddDependencies_CB_ARGS_DATA(cb_data) {};
// hipGraphAddKernelNode()
#define INIT_hipGraphAddKernelNode_CB_ARGS_DATA(cb_data) {};
// hipGraphAddMemcpyNode()
@@ -3148,10 +3159,26 @@ typedef struct hip_api_data_s {
#define INIT_hipGraphDestroy_CB_ARGS_DATA(cb_data) {};
// hipGraphExecDestroy()
#define INIT_hipGraphExecDestroy_CB_ARGS_DATA(cb_data) {};
// hipGraphGetNodes()
#define INIT_hipGraphGetNodes_CB_ARGS_DATA(cb_data) {};
// hipGraphGetRootNodes()
#define INIT_hipGraphGetRootNodes_CB_ARGS_DATA(cb_data) {};
// hipGraphInstantiate()
#define INIT_hipGraphInstantiate_CB_ARGS_DATA(cb_data) {};
// hipGraphKernelNodeGetParams()
#define INIT_hipGraphKernelNodeGetParams_CB_ARGS_DATA(cb_data) {};
// hipGraphKernelNodeSetParams()
#define INIT_hipGraphKernelNodeSetParams_CB_ARGS_DATA(cb_data) {};
// hipGraphLaunch()
#define INIT_hipGraphLaunch_CB_ARGS_DATA(cb_data) {};
// hipGraphMemcpyNodeGetParams()
#define INIT_hipGraphMemcpyNodeGetParams_CB_ARGS_DATA(cb_data) {};
// hipGraphMemcpyNodeSetParams()
#define INIT_hipGraphMemcpyNodeSetParams_CB_ARGS_DATA(cb_data) {};
// hipGraphMemsetNodeGetParams()
#define INIT_hipGraphMemsetNodeGetParams_CB_ARGS_DATA(cb_data) {};
// hipGraphMemsetNodeSetParams()
#define INIT_hipGraphMemsetNodeSetParams_CB_ARGS_DATA(cb_data) {};
// hipGraphicsGLRegisterBuffer()
#define INIT_hipGraphicsGLRegisterBuffer_CB_ARGS_DATA(cb_data) {};
// hipGraphicsMapResources()
@@ -2292,6 +2292,64 @@ inline static hipError_t hipGraphAddMemsetNode(hipGraphNode_t* pGraphNode, hipGr
cudaGraphAddMemsetNode(pGraphNode, graph, pDependencies, numDependencies, pMemsetParams));
}
inline static hipError_t hipGraphGetNodes(hipGraph_t graph, hipGraphNode_t* nodes,
size_t* numNodes) {
return hipCUDAErrorTohipError(cudaGraphGetNodes(graph, nodes, numNodes));
}
inline static hipError_t hipGraphGetRootNodes(hipGraph_t graph, hipGraphNode_t* pRootNodes,
size_t* pNumRootNodes) {
return hipCUDAErrorTohipError(cudaGraphGetRootNodes(graph, pRootNodes, pNumRootNodes));
}
inline static hipError_t hipGraphKernelNodeGetParams(hipGraphNode_t node,
hipKernelNodeParams* pNodeParams) {
return hipCUDAErrorTohipError(cudaGraphKernelNodeGetParams(node, pNodeParams));
}
inline static hipError_t hipGraphKernelNodeSetParams(hipGraphNode_t node,
const hipKernelNodeParams* pNodeParams) {
return hipCUDAErrorTohipError(cudaGraphKernelNodeSetParams(node, pNodeParams));
}
inline static hipError_t hipGraphMemcpyNodeGetParams(hipGraphNode_t node,
hipMemcpy3DParms* pNodeParams) {
return hipCUDAErrorTohipError(cudaGraphMemcpyNodeGetParams(node, pNodeParams));
}
inline static hipError_t hipGraphMemcpyNodeSetParams(hipGraphNode_t node,
const hipMemcpy3DParms* pNodeParams) {
return hipCUDAErrorTohipError(cudaGraphMemcpyNodeSetParams(node, pNodeParams));
}
inline static hipError_t hipGraphMemsetNodeGetParams(hipGraphNode_t node,
hipMemsetParams* pNodeParams) {
return hipCUDAErrorTohipError(cudaGraphMemsetNodeGetParams(node, pNodeParams));
}
inline static hipError_t hipGraphMemsetNodeSetParams(hipGraphNode_t node,
const hipMemsetParams* pNodeParams) {
return hipCUDAErrorTohipError(cudaGraphMemsetNodeSetParams(node, pNodeParams));
}
inline static hipError_t hipGraphExecKernelNodeSetParams(hipGraphExec_t hGraphExec,
hipGraphNode_t node,
const hipKernelNodeParams* pNodeParams) {
return hipCUDAErrorTohipError(cudaGraphExecKernelNodeSetParams(hGraphExec, node, pNodeParams));
}
inline static hipError_t hipGraphAddDependencies(hipGraph_t graph, const hipGraphNode_t* from,
const hipGraphNode_t* to, size_t numDependencies) {
return hipCUDAErrorTohipError(cudaGraphAddDependencies(graph, from, to, numDependencies));
}
inline static hipError_t hipGraphAddEmptyNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
const hipGraphNode_t* pDependencies,
size_t numDependencies) {
return hipCUDAErrorTohipError(
cudaGraphAddEmptyNode(pGraphNode, graph, pDependencies, numDependencies));
}
inline static hipError_t hipStreamWriteValue32(hipStream_t stream,
void* ptr, int32_t value, unsigned int flags) {
if (value < 0) {